* def extrair_infos_paginas(self, n_paginas=5, autosave=""): -Essa função serve pra pular para a próxima página e extrair as informações nela solicitadas

* def candidaturaLivre(self): -Essa função, presente no descritor, separa apenas as candidaturas livres

* def candidaturaPaga(self): -Essa função, presente no descritor, separa apenas as candidaturas pagas

* def homeOffice(self): -Essa função, presente no descritor, separa apenas as vagas HomeOffice

* def presencial(self): -Essa função, presente no descritor, separa apenas as vagas presenciais

* def combinar(self): -Essa função, presente no descritor, separa apenas os salários à combinar
